package redisrpc

import (
	"github.com/golang/protobuf/proto"
)

/**
 * 使用用户名查询
 */
func HGetString(key, field string, url ...string) (string, error) {

	conn, _, err := Conn(url...)

	if err != nil {
		return "", err
	}

	defer conn.Close()

	req := &HGetRequest{proto.String(key), proto.String(field), nil}

	res := &GetStringResponse{}

	err = conn.HGet(req, res)

	if err != nil {
		return "", err
	}

	return res.GetValue(), nil
}

//设置
func HSet(key, field, value string, url ...string) (uint64, error) {

	conn, _, err := Conn(url...)

	if err != nil {
		return 0, err
	}
	defer conn.Close()

	req := &HSetRequest{proto.String(key), proto.String(field), proto.String(value), nil}

	res := &HSetResponse{}

	err = conn.HSet(req, res)

	if err != nil {
		return 0, err
	}

	return res.GetRet(), nil
}

//删除
func HDel(key string, field string, url ...string) (uint64, error) {

	conn, _, err := Conn(url...)

	if err != nil {
		return 0, err
	}
	defer conn.Close()

	req := &HDelRequest{proto.String(key), proto.String(field), nil}

	res := &DelResponse{}

	err = conn.HDel(req, res)

	if err != nil {
		return 0, err
	}

	return res.GetRet(), nil
}
